// 
// Copyright (C) 2008, NinjaTrader LLC <www.ninjatrader.com>.
// NinjaTrader reserves the right to modify or overwrite this NinjaScript component with each release.
//

#region Using declarations
using System;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Indicator;
using NinjaTrader.Strategy;
#endregion

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    /// <summary>
    /// Sylvain Vervoort's minimal lag moving average crossover strategy as outlined in May 2008's issue of Traders' Tips for Stocks & Commodities magazine.
	/// Added the Short side and scaleouts with user definable targets, please run with Unique Entries option in the Strategy analyzer
    /// </summary>
    [Description("Please run with Unique entries option - Sylvain Vervoort's minimal lag moving average crossover strategy as outlined in May 2008's issue of TASC magazine.")]
    public class VervoortMACrossOver : Strategy
    {
        #region Variables
        private int period = 55; // Default setting for Period
        private double targetLong1  =  5;
		private double targetShort1 =  5;
		private double targetLong2  = 13;
		private double targetShort2 = 13;
		private double stopLoss     = 10;
		
		#endregion

        /// <summary>
        /// This method is used to configure the strategy and is called once before any strategy method is called.
        /// </summary>
        protected override void Initialize()
        {
			//Display the basic indicators from within the strategy
			Add(ZeroLagHATEMA(Period));
			Add(ZeroLagTEMA(Typical, Period));
			
			//Set coloring for our two indicators
			ZeroLagHATEMA(Period).Plots[0].Pen.Color = Color.Blue;
			ZeroLagTEMA(Typical, Period).Plots[0].Pen.Color = Color.Red;
			
			//Initialize the stop loss in ticks
			SetStopLoss(CalculationMode.Ticks, StopLoss);
			
			//Initialize 4 different profit targets for Long and Short trades
			SetProfitTarget("Long-1",CalculationMode.Ticks, TargetLong1);
			SetProfitTarget("Short-1",CalculationMode.Ticks, TargetShort1);
			SetProfitTarget("Long-2",CalculationMode.Ticks, TargetLong2);
			SetProfitTarget("Short-2",CalculationMode.Ticks, TargetShort2);
			
            CalculateOnBarClose = true;
        }

        /// <summary>
        /// Called on each bar update event (incoming tick)
        /// </summary>
        protected override void OnBarUpdate()
        {
			// Crossover generates Buy/Sell signal, unique order name attached to catch our targets above
			if (CrossAbove(ZeroLagTEMA(Typical, Period), ZeroLagHATEMA(Period), 1))
				EnterLong(1 , "Long-1");
			if (CrossBelow(ZeroLagTEMA(Typical, Period), ZeroLagHATEMA(Period), 1))
				EnterShort(1, "Short-1");
			
			if (CrossAbove(ZeroLagTEMA(Typical, Period), ZeroLagHATEMA(Period), 1))
				EnterLong(1 , "Long-2");
			if (CrossBelow(ZeroLagTEMA(Typical, Period), ZeroLagHATEMA(Period), 1))
				EnterShort(1, "Short-2");
        }

        #region Properties
        [Description("Numbers of bars used for calculations")]
        [Category("Parameters")]
        public int Period
        {
            get { return period; }
            set { period = Math.Max(1, value); }
        }
		
		[Description("Profit Target for first long contract")]
        [Category("Parameters")]
        public double TargetLong1
        {
            get { return targetLong1; }
            set { targetLong1 = Math.Max(1, value); }
        }
		
		[Description("Profit Target for second long contract")]
        [Category("Parameters")]
        public double TargetLong2
        {
            get { return targetLong2; }
            set { targetLong2 = Math.Max(1, value); }
        }
		
		[Description("Profit Target for first short contract")]
        [Category("Parameters")]
        public double TargetShort1
        {
            get { return targetShort1; }
            set { targetShort1 = Math.Max(1, value); }
        }
		
		[Description("Profit Target for second short contract")]
        [Category("Parameters")]
        public double TargetShort2
        {
            get { return targetShort2; }
            set { targetShort2 = Math.Max(1, value); }
        }
		
		[Description("Stop Loss for all contracts")]
        [Category("Parameters")]
        public double StopLoss
        {
            get { return stopLoss; }
            set { stopLoss = Math.Max(0, value); }
        }
        #endregion
    }
}
